==> kubernetes-model-resource-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha2/ResourceClaimSpecFluent.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ResourceClaimSpecFluent<A extends ResourceClaimSpecFluent<A>> extends BaseFluent<A>{
  public ResourceClaimSpecFluent() {
  }
  public ResourceClaimSpecFluent(ResourceClaimSpec instance) {
    instance = (instance != null ? instance : new ResourceClaimSpec());

    if (instance != null) {
      this.withAllocationMode(instance.getAllocationMode());
      this.withParametersRef(instance.getParametersRef());
      this.withResourceClassName(instance.getResourceClassName());
      this.withAllocationMode(instance.getAllocationMode());
      this.withParametersRef(instance.getParametersRef());
      this.withResourceClassName(instance.getResourceClassName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String allocationMode;
  private ResourceClaimParametersReferenceBuilder parametersRef;
  private String resourceClassName;
  private Map<String,Object> additionalProperties;
  public String getAllocationMode() {
    return this.allocationMode;
  }
  public A withAllocationMode(String allocationMode) {
    this.allocationMode=allocationMode; return (A) this;
  }
  public boolean hasAllocationMode() {
    return this.allocationMode != null;
  }
  public ResourceClaimParametersReference buildParametersRef() {
    return this.parametersRef!=null ?this.parametersRef.build():null;
  }
  public A withParametersRef(ResourceClaimParametersReference parametersRef) {
    _visitables.get("parametersRef").remove(this.parametersRef);
    if (parametersRef!=null){ this.parametersRef= new ResourceClaimParametersReferenceBuilder(parametersRef); _visitables.get("parametersRef").add(this.parametersRef);} else { this.parametersRef = null; _visitables.get("parametersRef").remove(this.parametersRef); } return (A) this;
  }
  public boolean hasParametersRef() {
    return this.parametersRef != null;
  }
  public A withNewParametersRef(String apiGroup,String kind,String name) {
    return (A)withParametersRef(new ResourceClaimParametersReference(apiGroup, kind, name));
  }
  public ParametersRefNested<A> withNewParametersRef() {
    return new ParametersRefNested(null);
  }
  public ParametersRefNested<A> withNewParametersRefLike(ResourceClaimParametersReference item) {
    return new ParametersRefNested(item);
  }
  public ParametersRefNested<A> editParametersRef() {
    return withNewParametersRefLike(java.util.Optional.ofNullable(buildParametersRef()).orElse(null));
  }
  public ParametersRefNested<A> editOrNewParametersRef() {
    return withNewParametersRefLike(java.util.Optional.ofNullable(buildParametersRef()).orElse(new ResourceClaimParametersReferenceBuilder().build()));
  }
  public ParametersRefNested<A> editOrNewParametersRefLike(ResourceClaimParametersReference item) {
    return withNewParametersRefLike(java.util.Optional.ofNullable(buildParametersRef()).orElse(item));
  }
  public String getResourceClassName() {
    return this.resourceClassName;
  }
  public A withResourceClassName(String resourceClassName) {
    this.resourceClassName=resourceClassName; return (A) this;
  }
  public boolean hasResourceClassName() {
    return this.resourceClassName != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ResourceClaimSpecFluent that = (ResourceClaimSpecFluent) o;
    if (!java.util.Objects.equals(allocationMode, that.allocationMode)) return false;

    if (!java.util.Objects.equals(parametersRef, that.parametersRef)) return false;

    if (!java.util.Objects.equals(resourceClassName, that.resourceClassName)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(allocationMode,  parametersRef,  resourceClassName,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (allocationMode != null) { sb.append("allocationMode:"); sb.append(allocationMode + ","); }
    if (parametersRef != null) { sb.append("parametersRef:"); sb.append(parametersRef + ","); }
    if (resourceClassName != null) { sb.append("resourceClassName:"); sb.append(resourceClassName + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ParametersRefNested<N> extends ResourceClaimParametersReferenceFluent<ParametersRefNested<N>> implements Nested<N>{
    ParametersRefNested(ResourceClaimParametersReference item) {
      this.builder = new ResourceClaimParametersReferenceBuilder(this, item);
    }
    ResourceClaimParametersReferenceBuilder builder;
    public N and() {
      return (N) ResourceClaimSpecFluent.this.withParametersRef(builder.build());
    }
    public N endParametersRef() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-resource-6.9.0-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha2/ResourceClaimSpecFluent.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ResourceClaimSpecFluent<A extends ResourceClaimSpecFluent<A>> extends BaseFluent<A>{
  public ResourceClaimSpecFluent() {
  }
  
  public ResourceClaimSpecFluent(ResourceClaimSpec instance) {
    this.copyInstance(instance);
  }
  private String allocationMode;
  private ResourceClaimParametersReferenceBuilder parametersRef;
  private String resourceClassName;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ResourceClaimSpec instance) {
    instance = (instance != null ? instance : new ResourceClaimSpec());
  
    if (instance != null) {
        this.withAllocationMode(instance.getAllocationMode());
        this.withParametersRef(instance.getParametersRef());
        this.withResourceClassName(instance.getResourceClassName());
        this.withAllocationMode(instance.getAllocationMode());
        this.withParametersRef(instance.getParametersRef());
        this.withResourceClassName(instance.getResourceClassName());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getAllocationMode() {
    return this.allocationMode;
  }
  
  public A withAllocationMode(String allocationMode) {
    this.allocationMode=allocationMode; return (A) this;
  }
  
  public boolean hasAllocationMode() {
    return this.allocationMode != null;
  }
  
  public ResourceClaimParametersReference buildParametersRef() {
    return this.parametersRef!=null ?this.parametersRef.build():null;
  }
  
  public A withParametersRef(ResourceClaimParametersReference parametersRef) {
    _visitables.get("parametersRef").remove(this.parametersRef);
    if (parametersRef!=null){ this.parametersRef= new ResourceClaimParametersReferenceBuilder(parametersRef); _visitables.get("parametersRef").add(this.parametersRef);} else { this.parametersRef = null; _visitables.get("parametersRef").remove(this.parametersRef); } return (A) this;
  }
  
  public boolean hasParametersRef() {
    return this.parametersRef != null;
  }
  
  public A withNewParametersRef(String apiGroup,String kind,String name) {
    return (A)withParametersRef(new ResourceClaimParametersReference(apiGroup, kind, name));
  }
  
  public ParametersRefNested<A> withNewParametersRef() {
    return new ParametersRefNested(null);
  }
  
  public ParametersRefNested<A> withNewParametersRefLike(ResourceClaimParametersReference item) {
    return new ParametersRefNested(item);
  }
  
  public ParametersRefNested<A> editParametersRef() {
    return withNewParametersRefLike(java.util.Optional.ofNullable(buildParametersRef()).orElse(null));
  }
  
  public ParametersRefNested<A> editOrNewParametersRef() {
    return withNewParametersRefLike(java.util.Optional.ofNullable(buildParametersRef()).orElse(new ResourceClaimParametersReferenceBuilder().build()));
  }
  
  public ParametersRefNested<A> editOrNewParametersRefLike(ResourceClaimParametersReference item) {
    return withNewParametersRefLike(java.util.Optional.ofNullable(buildParametersRef()).orElse(item));
  }
  
  public String getResourceClassName() {
    return this.resourceClassName;
  }
  
  public A withResourceClassName(String resourceClassName) {
    this.resourceClassName=resourceClassName; return (A) this;
  }
  
  public boolean hasResourceClassName() {
    return this.resourceClassName != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ResourceClaimSpecFluent that = (ResourceClaimSpecFluent) o;
    if (!java.util.Objects.equals(allocationMode, that.allocationMode)) return false;
  
    if (!java.util.Objects.equals(parametersRef, that.parametersRef)) return false;
  
    if (!java.util.Objects.equals(resourceClassName, that.resourceClassName)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(allocationMode,  parametersRef,  resourceClassName,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (allocationMode != null) { sb.append("allocationMode:"); sb.append(allocationMode + ","); }
    if (parametersRef != null) { sb.append("parametersRef:"); sb.append(parametersRef + ","); }
    if (resourceClassName != null) { sb.append("resourceClassName:"); sb.append(resourceClassName + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ParametersRefNested<N> extends ResourceClaimParametersReferenceFluent<ParametersRefNested<N>> implements Nested<N>{
    ParametersRefNested(ResourceClaimParametersReference item) {
      this.builder = new ResourceClaimParametersReferenceBuilder(this, item);
    }
    ResourceClaimParametersReferenceBuilder builder;
    
    public N and() {
      return (N) ResourceClaimSpecFluent.this.withParametersRef(builder.build());
    }
    
    public N endParametersRef() {
      return and();
    }
    
  
  }

}
